import { Level } from './level';
import { Display } from './display';
import { contain } from './include';
import { Log } from './log';
export class Logger {
    constructor(name, color, developmentMode, allowed, isMuted, fixedWidth) {
        this.name = name;
        this.color = color;
        this.developmentMode = developmentMode;
        this.allowed = allowed;
        this.isMuted = isMuted;
        this.fixedWidth = fixedWidth;
        /** @deprecated Use data(...)
         * @see data
        */
        this.d = (name, ...data) => this._data(name, data);
        /** @deprecated Use error(...)
         * @see error
        */
        this.er = (name, ...data) => this._error(name, data);
        /** @deprecated Use info(...)
         * @see info
        */
        this.i = (name, ...data) => this._info(name, data);
        /** @deprecated Use warn(...)
         * @see warn
        */
        this.w = (name, ...data) => this._warn(name, data);
        /**
         * Logs message and data with the level=data
         * @param message The message
         * @param otherParams Additional parameters
         */
        this.data = (message, ...otherParams) => { return this._data(message, otherParams); };
        /**
         * Logs message and data with the level=error
         * @param message The message
         * @param otherParams Additional parameters
         */
        this.error = (message, ...otherParams) => this._error(message, otherParams);
        /**
         * Logs message and data with the level=info
         * @param message The message
         * @param otherParams Additional parameters
         */
        this.info = (message, ...otherParams) => this._info(message, otherParams);
        /**
         * Logs message and data with the level=warn
         * @param message The message
         * @param otherParams Additional parameters
         */
        this.warn = (message, ...otherParams) => this._warn(message, otherParams);
        if (Array.isArray(Log.levels) && Log.levels.length > 0) {
            this.allowed = Log.levels;
        }
    }
    onlyWhen(expression) {
        if (typeof expression === 'function') {
            this.isMuted = !expression();
        }
        else if (typeof expression === 'boolean') {
            this.isMuted = !expression;
        }
    }
    _data(name, ...data) {
        if (this.isMuted)
            return this;
        if (this.allowed.length >= 1 && contain(this.allowed, Level.__NOTHING)
            && !contain(this.allowed, Level.DATA))
            return this;
        if (this.allowed.length === 0 || contain(this.allowed, Level.DATA)) {
            Display.msg.apply(undefined, [name, ...data, this.name, this.color, Level.DATA, this.fixedWidth]);
        }
        return this;
    }
    _error(name, ...data) {
        if (this.isMuted)
            return this;
        if (this.allowed.length >= 1 && contain(this.allowed, Level.__NOTHING)
            && !contain(this.allowed, Level.ERROR))
            return this;
        if (this.allowed.length === 0 || contain(this.allowed, Level.ERROR)) {
            Display.msg.apply(undefined, [name, ...data, this.name, this.color, Level.ERROR, this.fixedWidth]);
        }
        return this;
    }
    _info(name, ...data) {
        if (this.isMuted)
            return this;
        if (this.allowed.length >= 1 && contain(this.allowed, Level.__NOTHING)
            && !contain(this.allowed, Level.INFO))
            return this;
        if (this.allowed.length === 0 || contain(this.allowed, Level.INFO)) {
            Display.msg.apply(undefined, [name, ...data, this.name, this.color, Level.INFO, this.fixedWidth]);
        }
        return this;
    }
    _warn(name, ...data) {
        if (this.isMuted)
            return this;
        if (this.allowed.length >= 1 && contain(this.allowed, Level.__NOTHING)
            && !contain(this.allowed, Level.WARN))
            return this;
        if (this.allowed.length === 0 || contain(this.allowed, Level.WARN)) {
            Display.msg.apply(undefined, [name, ...data, this.name, this.color, Level.WARN, this.fixedWidth]);
        }
        return this;
    }
    level(l) {
        this._level = l;
        return this;
    }
    mute() {
        this.isMuted = true;
    }
}
Logger.isProductionMode = false;
//# sourceMappingURL=logger.js.map